Description Usage Arguments Value Author(s) References Examples
View source: R/Distributions.R
Calculates the transition graph of ordinal pattern for the given time series
1 | TransitionGraphs(series, dimension, delay)
|
series |
A numeric vector (e.g. a time series) |
dimension |
Dimension size of ordinal patterns |
delay |
Size of the embedding delay of ordinal patterns |
A numeric matrix containing the graph
Eduarda Chagas
Borges, João B., et al. "Learning and distinguishing time series dynamics via ordinal patterns transition graphs." Applied Mathematics and Computation 362 (2019): 124554.
1 2 3 4 5 | set.seed(123, kind = "Mersenne-Twister")
x <- runif(110000)
d <- 3
del <- 1
TransitionGraphs(series = x, dimension = d, delay = del)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.