Description Usage Arguments Value Author(s) References Examples
View source: R/Distributions.R
Calculates the weighted transition graph of ordinal pattern for the given time series
1 | WeightTransitionGraph(series, dimension, delay)
|
series |
A numeric vector (e.g. a time series) |
dimension |
Dimension size of ordinal patterns |
delay |
Size of the embedding delay of ordinal patterns |
A numeric matrix containing the graph
Eduarda Chagas
Chagas, Eduarda T. C., et al. "Analysis and Classification of SAR Textures using Information Theory" (2020)
1 2 3 4 5 | set.seed(123, kind = "Mersenne-Twister")
x <- runif(110000)
d <- 3
del <- 1
WeightTransitionGraph(series = x, dimension = d, delay = del)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.